/*
** Graphical User Interface using the Be API
** for Printer ACEpansion
*/

#include "acepansion.h"
#include "interface.h"

#include <Alert.h>
#include <Box.h>

#include "sys/haiku/PopASL.h"

#include <acepansion/lib_header.h>

#include "acepansion.h"
#include "interface.h"
#define CATCOMP_NUMBERS
#include "generated/locale_strings.h" /* catalog string ids */

class Container: public BBox
{
public:
	Container(struct ACEpansionPlugin* plugin)
		: BBox("printer settings")
		, myPlugin(plugin)
	{
		SetLabel(GetString(MSG_GROUP_TITLE));

		asl = new PopASL(0, GetString(MSG_LABEL_FILE), NULL,
			NULL, NULL, GetString(MSG_FILE_HELP), B_OPEN_PANEL, true, B_DIRECTORY_NODE);
		BGroupView* spacer = new BGroupView(B_VERTICAL);
		spacer->GroupLayout()->SetInsets(B_USE_SMALL_SPACING);
		spacer->AddChild(asl);
		AddChild(spacer);
		asl->SetMessage(new BMessage('FSEL'));
	}

	void AttachedToWindow()
	{
		asl->SetTarget(this);
	}

	void MessageReceived(BMessage* message)
	{
		switch (message->what)
		{
			case 'FSEL':
				Plugin_SetPrinterFileName(myPlugin, message->FindString("Name"));
				break;
			default:
				BBox::MessageReceived(message);
				break;
		}
	}

	void SetPrinterFileName(const char* name)
	{
		asl->TextControl()->SetText(name);
	}

private:
	PopASL* asl;
	struct ACEpansionPlugin* myPlugin;
};

/*
** Function which is called to initialize commons just
** after the library was loaded into memory and prior
** to any other API call
**
** This is the good place to open our required libraries
** and create our MUI custom classes
*/
BOOL GUI_InitResources(VOID)
{
	return TRUE;
}

/*
** Function which is called to free commons just before
** the library is expurged from memory
**
** This is the good place to close our required libraries
** and destroy our MUI custom classes
*/
VOID GUI_FreeResources(VOID)
{
}

/*
** Function which is called from CreatePlugin() to build the GUI
*/
Object* GUI_Create(struct ACEpansionPlugin* myPlugin)
{
	Container* container = new Container(myPlugin);

	return (Object*)container;
}

/*
** Function which is called from DeletePlugin() to delete the GUI
*/
VOID GUI_Delete(Object *gui)
{
	BView* view = (BView*)gui;
	BWindow* window = view->Window();
	window->Lock();
	view->RemoveSelf();
	window->Unlock();
	delete view;
}



/*
** Functions called from the plugin
*/
VOID GUI_SetPrinterFileName(Object *gui, CONST_STRPTR fileName)
{
	Container* container = (Container*)gui;
	container->SetPrinterFileName(fileName);
}

VOID GUI_NotifyPrinterFileError(UNUSED Object *gui, CONST_STRPTR fileName)
{
	BString message;
	message.SetToFormat(GetString(MSG_FILE_ERROR), fileName);
	BAlert* alert = new BAlert(GetString(MSG_TITLE), message, GetString(MSG_OK), NULL, NULL, B_WIDTH_AS_USUAL, B_WARNING_ALERT);
	alert->Go();
}

